---
title: KG이니시스 해외카드 서비스 이용안내
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
seo:
  title: KG이니시스 해외카드결제 서비스 이용안내
  description: >-
    KG이니시스의 해외카드결제 서비스를 통한 해외결제 이용방법 안내드립니다. KG이니시스의 지원결제 수단 및 특징, 입점기준, 예시화면,
    특약 신청방법, 참고사항까지 자세한 정보를 확인해보세요.
  keywords:
    - 해외카드
    - 이니시스 해외카드
    - 해외결제
tags:
  - KG이니시스
  - 해외결제
pgCompanies:
  - KG이니시스
searchTags:
  - 해외카드특약
  - KG이니시스 해외카드
  - 해외카드
  - KG이니시스 해외결제
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="KG이니시스를 통한 해외결제 이용방법 안내드립니다." />

#### **KG이니시스의 해외카드결제 서비스 이용안내**

1. **지원결제수단**

- 해외카드 (VISA, MASTER, JCB, DINERS)

**2. 지원 서비스 특징**

- 지원가능 통화 : KRW (승인/정산)
- 결제방식 : KG이니시스 결제창을 띄우는 방식으로만 가능
- 지원가능언어 : 한국어, 영어, 중국어
- 정산방식 : 원화정산

**3. 입점기준**

- KG이니시스와 계약을 맺으실 사업자의 서비스가 비실물 서비스인 ‘컨텐츠’ 일 경우 입점이 불가합니다.
- 국내사업자로만 계약이 가능합니다. (해외 법인 사업자 계약불가)
- KG이니시스를 통해 해외카드 사용 특약을 맺은 후 서비스 사용가능

**4. 예시 화면**





**5. 참고사항**

KG이니시스의 경우에는 해외카드 결제시 국내 카드 결제와 비슷하게 인증시스템(3D인증)을 거쳐야하기에 인증 절차가 없는 해외 결제자들에게는 결제를 하는데 다소 불편함이 있습니다.

**6. 특약 신청방법**

- [KG이니시스 상점관리자페이지](https://iniweb.inicis.com/) > 변경/추가 > 1.2.3 특약 서비스 추가 > 1. 해외카드 > 사용 선택 후 신청하기



<Callout content="" title="V2 KG이니시스 연동가이드 보러가기↗" />

<Callout content="" title="V1 KG이니시스 연동가이드 보러가기↗" />
